"use client"

import { Montserrat } from "next/font/google";
import { useState, useEffect } from "react";

import NavigationBar from "@/components/navigation_bar.component";
import { ThemeProvider } from "@/providers/theme.provider";
import { GlobalLayout, MainBlock } from "@/styles";
import Loader from "@/components/loader.component";

const inter = Montserrat({ subsets: ["latin"] });

export default function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode;
}>) {
  const [loading, setLoading] = useState(true);

  useEffect(() => {
    const handleComplete = () => setLoading(false);

    // simulate loading delay
    const timer = setTimeout(handleComplete, 1000);
    return () => clearTimeout(timer);
  }, []);

  return <>
    <html lang="en">
      {/* 
        can't use next.Metadata,
        because "use client" + styled components are 
        preventing it.

        next/head wouldn't work too, so legacy solution is used
      */}
      <head>
        <title>Parafia pw. Niepokalanego Serca NMP w Borzęcie</title>
        <meta name="description" content="Strona parafii pod wezwaniem Niepokalanego Serca Najświętszej Maryi Panny w Borzęcie." />
      </head>
      <body className={inter.className}>
        <ThemeProvider>
          <GlobalLayout />
          {loading
            ? <Loader />
            : <>
              <MainBlock>
                <NavigationBar />
                {children}
              </MainBlock>
            </>}
        </ThemeProvider>
      </body>
    </html>
  </>;
}